@@ -1,30 +1,33 @@
+"""Template tags used to render the tree editor."""
 import django
+from django.contrib.admin.templatetags.admin_list import _boolean_icon, result_headers
+from django.contrib.admin.utils import lookup_field
+from django.core.exceptions import ObjectDoesNotExist
 from django.db import models
 from django.template import Library
-from django.contrib.admin.templatetags.admin_list import result_headers, _boolean_icon
-from django.contrib.admin.utils import lookup_field
-from categories.editor.utils import display_for_field
-from django.core.exceptions import ObjectDoesNotExist
-from django.utils.encoding import smart_text, force_text
-from django.utils.html import escape, conditional_escape, escapejs, format_html
+from django.utils.encoding import force_str, smart_str
+from django.utils.html import conditional_escape, escape, escapejs, format_html
 from django.utils.safestring import mark_safe
 
 from categories.editor import settings
+from categories.editor.utils import display_for_field
 
 register = Library()
 
-TREE_LIST_RESULTS_TEMPLATE = 'admin/editor/tree_list_results.html'
+TREE_LIST_RESULTS_TEMPLATE = "admin/editor/tree_list_results.html"
 if settings.IS_GRAPPELLI_INSTALLED:
-    TREE_LIST_RESULTS_TEMPLATE = 'admin/editor/grappelli_tree_list_results.html'
+    TREE_LIST_RESULTS_TEMPLATE = "admin/editor/grappelli_tree_list_results.html"
 
 
 def get_empty_value_display(cl):
-    if hasattr(cl.model_admin, 'get_empty_value_display'):
+    """Get the value to display when empty."""
+    if hasattr(cl.model_admin, "get_empty_value_display"):
         return cl.model_admin.get_empty_value_display()
-    else:
-        # Django < 1.9
-        from django.contrib.admin.views.main import EMPTY_CHANGELIST_VALUE
-        return EMPTY_CHANGELIST_VALUE
+
+    # Django < 1.9
+    from django.contrib.admin.views.main import EMPTY_CHANGELIST_VALUE
+
+    return EMPTY_CHANGELIST_VALUE
 
 
 def items_for_tree_result(cl, result, form):
@@ -34,7 +37,7 @@ def items_for_tree_result(cl, result, form):
     first = True
     pk = cl.lookup_opts.pk.attname
     for field_name in cl.list_display:
-        row_class = ''
+        row_class = ""
         try:
             f, attr, value = lookup_field(field_name, result, cl.model_admin)
         except (AttributeError, ObjectDoesNotExist):
@@ -42,15 +45,15 @@ def items_for_tree_result(cl, result, form):
         else:
             if f is None:
                 if django.VERSION[0] == 1 and django.VERSION[1] == 4:
-                    if field_name == 'action_checkbox':
+                    if field_name == "action_checkbox":
                         row_class = ' class="action-checkbox disclosure"'
-                allow_tags = getattr(attr, 'allow_tags', False)
-                boolean = getattr(attr, 'boolean', False)
+                allow_tags = getattr(attr, "allow_tags", False)
+                boolean = getattr(attr, "boolean", False)
                 if boolean:
                     allow_tags = True
                     result_repr = _boolean_icon(value)
                 else:
-                    result_repr = smart_text(value)
+                    result_repr = smart_str(value)
                 # Strip HTML tags in the resulting text, except if the
                 # function has an "allow_tags" attribute set to True.
                 if not allow_tags:
@@ -60,16 +63,16 @@ def items_for_tree_result(cl, result, form):
             else:
                 if value is None:
                     result_repr = get_empty_value_display(cl)
-                if hasattr(f, 'rel') and isinstance(f.rel, models.ManyToOneRel):
+                if hasattr(f, "rel") and isinstance(f.rel, models.ManyToOneRel):
                     result_repr = escape(getattr(result, f.name))
                 else:
-                    result_repr = display_for_field(value, f, '')
+                    result_repr = display_for_field(value, f, "")
                 if isinstance(f, models.DateField) or isinstance(f, models.TimeField):
                     row_class = ' class="nowrap"'
             if first:
                 if django.VERSION[0] == 1 and django.VERSION[1] < 4:
                     try:
-                        f, attr, checkbox_value = lookup_field('action_checkbox', result, cl.model_admin)
+                        f, attr, checkbox_value = lookup_field("action_checkbox", result, cl.model_admin)
                         if row_class:
                             row_class = "%s%s" % (row_class[:-1], ' disclosure"')
                         else:
@@ -77,14 +80,14 @@ def items_for_tree_result(cl, result, form):
                     except (AttributeError, ObjectDoesNotExist):
                         pass
 
-        if force_text(result_repr) == '':
-            result_repr = mark_safe('&nbsp;')
+        if force_str(result_repr) == "":
+            result_repr = mark_safe("&nbsp;")
         # If list_display_links not defined, add the link tag to the first field
         if (first and not cl.list_display_links) or field_name in cl.list_display_links:
             if django.VERSION[0] == 1 and django.VERSION[1] < 4:
-                table_tag = 'td'  # {True:'th', False:'td'}[first]
+                table_tag = "td"  # {True:'th', False:'td'}[first]
             else:
-                table_tag = {True: 'th', False: 'td'}[first]
+                table_tag = {True: "th", False: "td"}[first]
 
             url = cl.url_for_result(result)
             # Convert the pk to something that can be used in Javascript.
@@ -94,19 +97,24 @@ def items_for_tree_result(cl, result, form):
             else:
                 attr = pk
             value = result.serializable_value(attr)
-            result_id = repr(force_text(value))[1:]
+            result_id = repr(force_str(value))[1:]
             first = False
             result_id = escapejs(value)
             yield mark_safe(
                 format_html(
-                    smart_text('<{}{}><a href="{}"{}>{}</a></{}>'),
+                    smart_str('<{}{}><a href="{}"{}>{}</a></{}>'),
                     table_tag,
                     row_class,
                     url,
                     format_html(
-                        ' onclick="opener.dismissRelatedLookupPopup(window, '
-                        '&#39;{}&#39;); return false;"', result_id
-                    ) if cl.is_popup else '', result_repr, table_tag)
+                        ' onclick="opener.dismissRelatedLookupPopup(window, ' '&#39;{}&#39;); return false;"',
+                        result_id,
+                    )
+                    if cl.is_popup
+                    else "",
+                    result_repr,
+                    table_tag,
+                )
             )
 
         else:
@@ -115,23 +123,26 @@ def items_for_tree_result(cl, result, form):
             # can provide fields on a per request basis
             if form and field_name in form.fields:
                 bf = form[field_name]
-                result_repr = mark_safe(force_text(bf.errors) + force_text(bf))
+                result_repr = mark_safe(force_str(bf.errors) + force_str(bf))
             else:
                 result_repr = conditional_escape(result_repr)
-            yield mark_safe(smart_text('<td%s>%s</td>' % (row_class, result_repr)))
+            yield mark_safe(smart_str("<td%s>%s</td>" % (row_class, result_repr)))
     if form and not form[cl.model._meta.pk.name].is_hidden:
-        yield mark_safe(smart_text('<td>%s</td>' % force_text(form[cl.model._meta.pk.name])))
+        yield mark_safe(smart_str("<td>%s</td>" % force_str(form[cl.model._meta.pk.name])))
 
 
 class TreeList(list):
+    """A list subclass for tree result."""
+
     pass
 
 
 def tree_results(cl):
+    """Generates a list of results for the tree."""
     if cl.formset:
         for res, form in zip(cl.result_list, cl.formset.forms):
             result = TreeList(items_for_tree_result(cl, res, form))
-            if hasattr(res, 'pk'):
+            if hasattr(res, "pk"):
                 result.pk = res.pk
                 if res.parent:
                     result.parent_pk = res.parent.pk
@@ -141,7 +152,7 @@ def tree_results(cl):
     else:
         for res in cl.result_list:
             result = TreeList(items_for_tree_result(cl, res, None))
-            if hasattr(res, 'pk'):
+            if hasattr(res, "pk"):
                 result.pk = res.pk
                 if res.parent:
                     result.parent_pk = res.parent.pk
@@ -152,17 +163,15 @@ def tree_results(cl):
 
 def result_tree_list(cl):
     """
-    Displays the headers and data list together
+    Displays the headers and data list together.
     """
     import django
-    result = {
-        'cl': cl,
-        'result_headers': list(result_headers(cl)),
-        'results': list(tree_results(cl))
-    }
+
+    result = {"cl": cl, "result_headers": list(result_headers(cl)), "results": list(tree_results(cl))}
     if django.VERSION[0] == 1 and django.VERSION[1] > 2:
         from django.contrib.admin.templatetags.admin_list import result_hidden_fields
-        result['result_hidden_fields'] = list(result_hidden_fields(cl))
+
+        result["result_hidden_fields"] = list(result_hidden_fields(cl))
     return result
 
 
