@@ -1,25 +1,24 @@
+"""Custom category fields for other models."""
 from django.db.models import ForeignKey, ManyToManyField
 
 
 class CategoryM2MField(ManyToManyField):
+    """A many to many field to a Category model."""
+
     def __init__(self, **kwargs):
         from .models import Category
-        if 'to' in kwargs:
-            kwargs.pop('to')
+
+        if "to" in kwargs:
+            kwargs.pop("to")
         super(CategoryM2MField, self).__init__(to=Category, **kwargs)
 
 
 class CategoryFKField(ForeignKey):
+    """A foreign key to the Category model."""
+
     def __init__(self, **kwargs):
         from .models import Category
-        if 'to' in kwargs:
-            kwargs.pop('to')
+
+        if "to" in kwargs:
+            kwargs.pop("to")
         super(CategoryFKField, self).__init__(to=Category, **kwargs)
-
-
-try:
-    from south.modelsinspector import add_introspection_rules
-    add_introspection_rules([], [r"^categories\.fields\.CategoryFKField"])
-    add_introspection_rules([], [r"^categories\.fields\.CategoryM2MField"])
-except ImportError:
-    pass
