@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 from django.core import management
 from django.core.management.base import CommandError
 from django.db import connection
@@ -6,7 +5,6 @@ from django.test import TestCase
 
 
 class TestMgmtCommands(TestCase):
-
     @classmethod
     def setUpClass(cls):
         connection.disable_constraint_checking()
@@ -18,13 +16,13 @@ class TestMgmtCommands(TestCase):
         connection.enable_constraint_checking()
 
     def test_add_category_fields(self):
-        management.call_command('add_category_fields', verbosity=0)
+        management.call_command("add_category_fields", verbosity=0)
 
     def test_add_category_fields_app(self):
-        management.call_command('add_category_fields', 'flatpages', verbosity=0)
+        management.call_command("add_category_fields", "flatpages", verbosity=0)
 
     def test_drop_category_field(self):
-        management.call_command('drop_category_field', 'flatpages', 'flatpage', 'category', verbosity=0)
+        management.call_command("drop_category_field", "flatpages", "flatpage", "category", verbosity=0)
 
     def test_drop_category_field_error(self):
-        self.assertRaises(CommandError, management.call_command, 'drop_category_field', verbosity=0)
+        self.assertRaises(CommandError, management.call_command, "drop_category_field", verbosity=0)
